#!/bin/bash
##########################################
# File Name:17_check_file.sh
# Version:V3.0
# Author:zhangpeng
# Organization:linuxjk.cn
# Desc: 检查是否为文件,是否为目录,是否具有执行权限.增强文件类型检测（支持软链接）
###########################################

# 参数检查
[ $# -ne 1 ] && { echo "用法: sh $0 文件/目录"; exit 1; }

file="$1"

# 存在性检查
[ ! -e "$file" ] && { echo "错误：$file 不存在！"; exit 1; }

# 类型检测（按检测顺序排序）
#如果软连接指向文件/目录，先检测-f/-d会检测软连接指向的那个文件/目录，所以先检测软连接
if [ -L "$file" ]; then
    type="软链接"
   # target=$(readlink -f "$file")
    
    # 检查目标文件权限
    if [ -x "$target" ]; then
        perm="目标文件有执行权限"
    else
        perm="目标文件无执行权限"
    fi
    
elif [ -f "$file" ]; then
    type="普通文件"
    [ -x "$file" ] && perm="有执行权限" || perm="没有执行权限"
    
elif [ -d "$file" ]; then
    type="目录"
    [ -x "$file" ] && perm="有执行权限" || perm="无执行权限"
    
else
    echo "$file 存在，但无法识别类型（可能是设备文件、管道文件等）"
    exit 1
fi

echo "$file 类型：${type}，${perm}"
